@@ -64,6 +64,7 @@ class CensiusClient(object):
                     "key": Key,
                     "type": Type,
                     "apiKey": self.api_key,
+                    "tenantKey": self.tenantKey,
                 }.items()
                 if v
             }
@@ -190,6 +191,7 @@ class CensiusClient(object):
             "unixInterval": unixInterval,
             "timestampType": timestampType,
             "rawValues": json.dumps(rawValues),
+            "tenantKey":self.tenantKey,
         }
         files = [("File", (file_name, open(os.getcwd() + "/" + file_name, "rb"), "text/csv"))]
 
@@ -260,7 +262,7 @@ class CensiusClient(object):
                     "name": kwargs["model_name"],
                     "projectId": kwargs["project_id"],
                     "type": kwargs["model_type"],
-                    "target": targets,
+                    "targets": targets,
                     "features": features,
                     "apiKey": self.api_key,
                     "windowSize": WindowSize,
@@ -330,6 +332,7 @@ class CensiusClient(object):
                     "version": kwargs["model_version"],
                     "isRollingWindow": IsRollingWindow,
                     "apiKey": self.api_key,
+                    "tenantKey":self.tenantKey,
                     "windowSize": WindowSize,
                     "window_start_time": WindowStartTime,
                     "window_end_time": WindowEndTime,
