@@ -439,10 +439,29 @@ class BulkLogProcessing:
                 print(" [info] Bulk Log Processing Ended.")
                 return thread_response
 
+    def _reformat_explain_row(self, single_row: dict) -> dict:
+        single_row = single_row.drop("log_id")
+        return dict(zip(single_row.index, single_row.values))
+
+    def _restructure_bulk_explain_df(self, input_dataframe: pd.DataFrame) -> pd.DataFrame:
+        restructure_dataframe = pd.DataFrame(columns=["log_id", "shap_values"])
+        input_dataframe["shap_values"] = input_dataframe.apply(
+            lambda x: self._reformat_explain_row(x), axis=1
+        )
+        # copy log_id, shape_value column to restructure_dataframe
+        restructure_dataframe[["log_id", "shap_values"]] = input_dataframe[
+            ["log_id", "shap_values"]
+        ]
+        # delete input_dataframe
+        del input_dataframe
+        return restructure_dataframe
+
     def process_bulk_explain(
         self, input_dataframe: pd.DataFrame, headers: dict, model_details: dict
     ) -> dict:
 
+        # restructure input_dataframe
+        input_dataframe = self._restructure_bulk_explain_df(input_dataframe)
         pool = ThreadPool(processes=1)
         background_worker_thread = pool.apply_async(
             self._dataframe_chunks,
